@@ -23,28 +23,36 @@ Author: Aidan Jungo
 """
 
 import os
+from pathlib import Path
+
 import pandas as pd
 
 from cpacspy.aeromap import AeroMap
 from cpacspy.aircraft import Aircraft
-from cpacspy.cpacsfunctions import open_tigl, open_tixi, get_xpath_parent
+from cpacspy.cpacsfunctions import get_xpath_parent, open_tigl, open_tixi
 from cpacspy.utils import AEROPERFORMANCE_XPATH
 
+from src.cpacspy.utils import AC_NAME_XPATH
+
 
 class CPACS:
-    """ CPACS class """
+    """CPACS class"""
 
     def __init__(self, cpacs_file):
 
+        # To accept either a Path or a string
+        if isinstance(cpacs_file, Path):
+            self.cpacs_file = str(cpacs_file)
+        else:
+            self.cpacs_file = cpacs_file
+
         # CPACS
-        self.cpacs_file = cpacs_file
         self.tixi = open_tixi(cpacs_file)
         self.tigl = open_tigl(self.tixi)
 
         # Aircraft name
-        ac_name_xpath = "/cpacs/header/name"
-        if self.tixi.checkElement(ac_name_xpath):
-            self.ac_name = self.tixi.getTextElement(ac_name_xpath)
+        if self.tixi.checkElement(AC_NAME_XPATH):
+            self.ac_name = self.tixi.getTextElement(AC_NAME_XPATH)
 
         # Aircraft data
         self.aircraft = Aircraft(self.tixi, self.tigl)
@@ -53,7 +61,7 @@ class CPACS:
         self.load_all_aeromaps()
 
     def load_all_aeromaps(self):
-        """ Load all the aeromaps present in the CPACS file as object. """
+        """Load all the aeromaps present in the CPACS file as object."""
 
         self.nb_aeromaps = 0
         self.aeromaps = []
@@ -64,7 +72,7 @@ class CPACS:
             self.nb_aeromaps += 1
 
     def get_aeromap_uid_list(self):
-        """ Get the list of all aeroMap UID. """
+        """Get the list of all aeroMap UID."""
 
         uid_list = []
 
@@ -83,7 +91,7 @@ class CPACS:
         return uid_list
 
     def get_aeromap_by_uid(self, uid):
-        """ Get an aeromap object by its uid. """
+        """Get an aeromap object by its uid."""
 
         for aeromap in self.aeromaps:
             if aeromap.uid == uid:
@@ -92,7 +100,7 @@ class CPACS:
         raise ValueError(f'No aeromap with "{uid}" as uid as been found!')
 
     def create_aeromap(self, uid):
-        """ Create a new aeromap object. """
+        """Create a new aeromap object."""
 
         if " " in uid:
             raise ValueError("AeroMap uid should not contain any space!")
@@ -106,7 +114,7 @@ class CPACS:
             raise ValueError("This uid already exit!")
 
     def create_aeromap_from_csv(self, csv_path, uid=None):
-        """ Create a new aeromap object from a CSV file. """
+        """Create a new aeromap object from a CSV file."""
 
         if not uid:
             _, tail = os.path.split(csv_path)
@@ -121,7 +129,7 @@ class CPACS:
         return new_aeromap
 
     def duplicate_aeromap(self, uid_base, uid_duplicate):
-        """ Duplicate an aeromap and retrun the new aeromap object. """
+        """Duplicate an aeromap and retrun the new aeromap object."""
 
         # Check uid's
         if uid_base not in self.get_aeromap_uid_list():
@@ -144,7 +152,7 @@ class CPACS:
         return am_duplicated
 
     def delete_aeromap(self, uid):
-        """ Delete an aeromap from its uid. """
+        """Delete an aeromap from its uid."""
 
         # Check if uid is valid
         if " " in uid:
@@ -162,7 +170,13 @@ class CPACS:
         self.load_all_aeromaps()
 
     def save_cpacs(self, cpacs_file, overwrite=False):
-        """ Save a CPACS file from the TIXI object at a chosen path. """
+        """Save a CPACS file from the TIXI object at a chosen path."""
+
+        # To accept either a Path or a string
+        if isinstance(cpacs_file, Path):
+            cpacs_file = str(cpacs_file)
+        else:
+            cpacs_file = cpacs_file
 
         # Check for .xml file
         if not cpacs_file.endswith(".xml"):
